rest property

Grammar? get rest

An additional grammar whose rules are applied after tokens (used by templating languages to fall back to a host grammar). Stored as a thunk so it can reference other languages without cycles.

Implementation

Grammar? get rest => _rest?.call();